from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DdmCls:
	"""Ddm commands group definition. 8 total commands, 0 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ddm", core, parent)

	# noinspection PyTypeChecker
	def get_coupling(self) -> enums.AvionicIlsDdmCoup:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:COUPling \n
		Snippet: value: enums.AvionicIlsDdmCoup = driver.source.bb.ils.gs.ddm.get_coupling() \n
		Selects if the DDM value is fixed or is changed with a change of sum of modulation depths (SDM,
		see [:SOURce<hw>][:BB]:ILS[:GS|GSLope]:SDM) . \n
			:return: coupling: FIXed| SDM
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:GS:DDM:COUPling?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicIlsDdmCoup)

	def set_coupling(self, coupling: enums.AvionicIlsDdmCoup) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:COUPling \n
		Snippet: driver.source.bb.ils.gs.ddm.set_coupling(coupling = enums.AvionicIlsDdmCoup.FIXed) \n
		Selects if the DDM value is fixed or is changed with a change of sum of modulation depths (SDM,
		see [:SOURce<hw>][:BB]:ILS[:GS|GSLope]:SDM) . \n
			:param coupling: FIXed| SDM
		"""
		param = Conversions.enum_scalar_to_str(coupling, enums.AvionicIlsDdmCoup)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:GS:DDM:COUPling {param}')

	def get_current(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:CURRent \n
		Snippet: value: float = driver.source.bb.ils.gs.ddm.get_current() \n
		Sets the DDM value alternatively as a current by means of the ILS indicating instrument. The instrument current is
		calculated according to: DDM Current uA = DDM Depth [%] x 857,125 uA A variation of the instrument current automatically
		leads to a variation of the DDM value and the DDM value in dB. \n
			:return: current: float Range: -8.57125E-4 to 8.57125E-4
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:GS:DDM:CURRent?')
		return Conversions.str_to_float(response)

	def set_current(self, current: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:CURRent \n
		Snippet: driver.source.bb.ils.gs.ddm.set_current(current = 1.0) \n
		Sets the DDM value alternatively as a current by means of the ILS indicating instrument. The instrument current is
		calculated according to: DDM Current uA = DDM Depth [%] x 857,125 uA A variation of the instrument current automatically
		leads to a variation of the DDM value and the DDM value in dB. \n
			:param current: float Range: -8.57125E-4 to 8.57125E-4
		"""
		param = Conversions.decimal_value_to_str(current)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:GS:DDM:CURRent {param}')

	# noinspection PyTypeChecker
	def get_direction(self) -> enums.UpDownDirection:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:DIRection \n
		Snippet: value: enums.UpDownDirection = driver.source.bb.ils.gs.ddm.get_direction() \n
		Sets the simulation mode for the ILS glide slope modulation signal. A change of the setting automatically changes the
		sign of the DDM value. \n
			:return: direction: UP| DOWN UP The 150 Hz modulation signal is predominant, the DDM value is negative (the airplane is too low, it must climb) . DOWN The 90 Hz modulation signal is predominant, the DDM value is positive (the airplane is too high, it must descend) .
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:GS:DDM:DIRection?')
		return Conversions.str_to_scalar_enum(response, enums.UpDownDirection)

	def set_direction(self, direction: enums.UpDownDirection) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:DIRection \n
		Snippet: driver.source.bb.ils.gs.ddm.set_direction(direction = enums.UpDownDirection.DOWN) \n
		Sets the simulation mode for the ILS glide slope modulation signal. A change of the setting automatically changes the
		sign of the DDM value. \n
			:param direction: UP| DOWN UP The 150 Hz modulation signal is predominant, the DDM value is negative (the airplane is too low, it must climb) . DOWN The 90 Hz modulation signal is predominant, the DDM value is positive (the airplane is too high, it must descend) .
		"""
		param = Conversions.enum_scalar_to_str(direction, enums.UpDownDirection)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:GS:DDM:DIRection {param}')

	def get_logarithmic(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:LOGarithmic \n
		Snippet: value: float = driver.source.bb.ils.gs.ddm.get_logarithmic() \n
		Sets the depth of modulation value for ILS glide slope modulation in dB.
		See also [:SOURce<hw>][:BB]:ILS[:GS|GSLope]:DDM[:DEPTh]. \n
			:return: logarithmic: float Range: -999.9 to 999.9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:GS:DDM:LOGarithmic?')
		return Conversions.str_to_float(response)

	def set_logarithmic(self, logarithmic: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:LOGarithmic \n
		Snippet: driver.source.bb.ils.gs.ddm.set_logarithmic(logarithmic = 1.0) \n
		Sets the depth of modulation value for ILS glide slope modulation in dB.
		See also [:SOURce<hw>][:BB]:ILS[:GS|GSLope]:DDM[:DEPTh]. \n
			:param logarithmic: float Range: -999.9 to 999.9
		"""
		param = Conversions.decimal_value_to_str(logarithmic)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:GS:DDM:LOGarithmic {param}')

	def get_pct(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:PCT \n
		Snippet: value: float = driver.source.bb.ils.gs.ddm.get_pct() \n
		Sets the difference in depth of modulation between the signal of the upper lobe (90 Hz) and the lower lobe (150 Hz) . The
		maximum value equals the sum of the modulation depths of the 90 Hz and the 150 Hz tone.
		See also [:SOURce<hw>][:BB]:ILS[:GS|GSLope]:DDM[:DEPTh]. \n
			:return: pct: float Range: -80.0 to 80.0
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:GS:DDM:PCT?')
		return Conversions.str_to_float(response)

	def set_pct(self, pct: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:PCT \n
		Snippet: driver.source.bb.ils.gs.ddm.set_pct(pct = 1.0) \n
		Sets the difference in depth of modulation between the signal of the upper lobe (90 Hz) and the lower lobe (150 Hz) . The
		maximum value equals the sum of the modulation depths of the 90 Hz and the 150 Hz tone.
		See also [:SOURce<hw>][:BB]:ILS[:GS|GSLope]:DDM[:DEPTh]. \n
			:param pct: float Range: -80.0 to 80.0
		"""
		param = Conversions.decimal_value_to_str(pct)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:GS:DDM:PCT {param}')

	# noinspection PyTypeChecker
	def get_polarity(self) -> enums.AvionicIlsDdmPol:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:POLarity \n
		Snippet: value: enums.AvionicIlsDdmPol = driver.source.bb.ils.gs.ddm.get_polarity() \n
		Sets the polarity for DDM calculation (see [:SOURce<hw>][:BB]:ILS[:GS|GSLope]:DDM[:DEPTh]) . The DDM depth calculation
		depends on the selected polarity:
			INTRO_CMD_HELP: Selects the trigger mode: \n
			- Polarity 90 Hz - 150 Hz (default setting) : DDM = [ AM (90 Hz) - AM (150 Hz) ] / 100%
			- Polarity 150 Hz - 90 Hz: DDM = [ AM (150 Hz) - AM (90 Hz) ] / 100% \n
			:return: polarity: P90_150| P150_90
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:GS:DDM:POLarity?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicIlsDdmPol)

	def set_polarity(self, polarity: enums.AvionicIlsDdmPol) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:POLarity \n
		Snippet: driver.source.bb.ils.gs.ddm.set_polarity(polarity = enums.AvionicIlsDdmPol.P150_90) \n
		Sets the polarity for DDM calculation (see [:SOURce<hw>][:BB]:ILS[:GS|GSLope]:DDM[:DEPTh]) . The DDM depth calculation
		depends on the selected polarity:
			INTRO_CMD_HELP: Selects the trigger mode: \n
			- Polarity 90 Hz - 150 Hz (default setting) : DDM = [ AM (90 Hz) - AM (150 Hz) ] / 100%
			- Polarity 150 Hz - 90 Hz: DDM = [ AM (150 Hz) - AM (90 Hz) ] / 100% \n
			:param polarity: P90_150| P150_90
		"""
		param = Conversions.enum_scalar_to_str(polarity, enums.AvionicIlsDdmPol)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:GS:DDM:POLarity {param}')

	# noinspection PyTypeChecker
	def get_step(self) -> enums.AvionicDdmStep:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:STEP \n
		Snippet: value: enums.AvionicDdmStep = driver.source.bb.ils.gs.ddm.get_step() \n
		Sets the variation of the difference in depth of modulation via the rotary knob. \n
			:return: ddm_step: DECimal| PREDefined
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:GS:DDM:STEP?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicDdmStep)

	def set_step(self, ddm_step: enums.AvionicDdmStep) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:STEP \n
		Snippet: driver.source.bb.ils.gs.ddm.set_step(ddm_step = enums.AvionicDdmStep.DECimal) \n
		Sets the variation of the difference in depth of modulation via the rotary knob. \n
			:param ddm_step: DECimal| PREDefined
		"""
		param = Conversions.enum_scalar_to_str(ddm_step, enums.AvionicDdmStep)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:GS:DDM:STEP {param}')

	def get_depth(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:[DEPTh] \n
		Snippet: value: float = driver.source.bb.ils.gs.ddm.get_depth() \n
		Sets the difference in depth of modulation between the signal of the upper/left lobe (90 Hz) and the lower/right lobe
		(150 Hz) . The maximum value equals the sum of the modulation depths of the 90 Hz and the 150 Hz tone. The following is
		true: ILS:GS|GSL:DDM:DEPTh = (AM(90Hz) - AM(150Hz) )/100% A variation of the DDM value automatically leads to a variation
		of the DDM value in dB and the value of the instrument current. \n
			:return: depth: float Range: -0.8 to 0.8
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:GS:DDM:DEPTh?')
		return Conversions.str_to_float(response)

	def set_depth(self, depth: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:[GS]:DDM:[DEPTh] \n
		Snippet: driver.source.bb.ils.gs.ddm.set_depth(depth = 1.0) \n
		Sets the difference in depth of modulation between the signal of the upper/left lobe (90 Hz) and the lower/right lobe
		(150 Hz) . The maximum value equals the sum of the modulation depths of the 90 Hz and the 150 Hz tone. The following is
		true: ILS:GS|GSL:DDM:DEPTh = (AM(90Hz) - AM(150Hz) )/100% A variation of the DDM value automatically leads to a variation
		of the DDM value in dB and the value of the instrument current. \n
			:param depth: float Range: -0.8 to 0.8
		"""
		param = Conversions.decimal_value_to_str(depth)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:GS:DDM:DEPTh {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SttmCls:
	"""Sttm commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sttm", core, parent)

	def set(self, start_time: enums.EutraPracNbiotStartTimeMs, configurationNull=repcap.ConfigurationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:PRACh:NIOT:CFG<CH0>:STTM \n
		Snippet: driver.source.bb.eutra.uplink.prach.niot.cfg.sttm.set(start_time = enums.EutraPracNbiotStartTimeMs._10, configurationNull = repcap.ConfigurationNull.Default) \n
		Sets the start time of the specific NPRACH configuration. \n
			:param start_time: 8| 16| 64| 128| 32| 256| 512| 1024 | 10| 20| 40| 80| 160| 320| 640| 1280| 2560| 5120
			:param configurationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cfg')
		"""
		param = Conversions.enum_scalar_to_str(start_time, enums.EutraPracNbiotStartTimeMs)
		configurationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(configurationNull, repcap.ConfigurationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:PRACh:NIOT:CFG{configurationNull_cmd_val}:STTM {param}')

	# noinspection PyTypeChecker
	def get(self, configurationNull=repcap.ConfigurationNull.Default) -> enums.EutraPracNbiotStartTimeMs:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:PRACh:NIOT:CFG<CH0>:STTM \n
		Snippet: value: enums.EutraPracNbiotStartTimeMs = driver.source.bb.eutra.uplink.prach.niot.cfg.sttm.get(configurationNull = repcap.ConfigurationNull.Default) \n
		Sets the start time of the specific NPRACH configuration. \n
			:param configurationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cfg')
			:return: start_time: 8| 16| 64| 128| 32| 256| 512| 1024 | 10| 20| 40| 80| 160| 320| 640| 1280| 2560| 5120"""
		configurationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(configurationNull, repcap.ConfigurationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:PRACh:NIOT:CFG{configurationNull_cmd_val}:STTM?')
		return Conversions.str_to_scalar_enum(response, enums.EutraPracNbiotStartTimeMs)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SgDefinitionCls:
	"""SgDefinition commands group definition. 8 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sgDefinition", core, parent)

	@property
	def a(self):
		"""a commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_a'):
			from .A import ACls
			self._a = ACls(self._core, self._cmd_group)
		return self._a

	@property
	def b(self):
		"""b commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_b'):
			from .B import BCls
			self._b = BCls(self._core, self._cmd_group)
		return self._b

	@property
	def c(self):
		"""c commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_c'):
			from .C import CCls
			self._c = CCls(self._core, self._cmd_group)
		return self._c

	@property
	def d(self):
		"""d commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_d'):
			from .D import DCls
			self._d = DCls(self._core, self._cmd_group)
		return self._d

	@property
	def e(self):
		"""e commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_e'):
			from .E import ECls
			self._e = ECls(self._core, self._cmd_group)
		return self._e

	@property
	def f(self):
		"""f commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_f'):
			from .F import FCls
			self._f = FCls(self._core, self._cmd_group)
		return self._f

	@property
	def g(self):
		"""g commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_g'):
			from .G import GCls
			self._g = GCls(self._core, self._cmd_group)
		return self._g

	@property
	def h(self):
		"""h commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_h'):
			from .H import HCls
			self._h = HCls(self._core, self._cmd_group)
		return self._h

	def clone(self) -> 'SgDefinitionCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SgDefinitionCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UsedCls:
	"""Used commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("used", core, parent)

	def get(self, monitorPane=repcap.MonitorPane.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:MONitor<CH>:DISPlay:CHANnels:USED \n
		Snippet: value: int = driver.source.bb.gnss.monitor.display.channels.used.get(monitorPane = repcap.MonitorPane.Default) \n
		Queries the number of active channels. The maximum number of active channels depends on the installed options, see
		'Channel budget'. \n
			:param monitorPane: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Monitor')
			:return: used_channels: integer Range: 0 to depends on installed options The *RST value depends on the installed GNSS system option, e.g. for GPS : *RST: 11"""
		monitorPane_cmd_val = self._cmd_group.get_repcap_cmd_value(monitorPane, repcap.MonitorPane)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:MONitor{monitorPane_cmd_val}:DISPlay:CHANnels:USED?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModulationCls:
	"""Modulation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("modulation", core, parent)

	# noinspection PyTypeChecker
	def get(self, frameBlock=repcap.FrameBlock.Default) -> enums.ModulationF:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:PSDU:MODulation \n
		Snippet: value: enums.ModulationF = driver.source.bb.wlnn.fblock.psdu.modulation.get(frameBlock = repcap.FrameBlock.Default) \n
		(available only for CCK and PBCC Tx modes) Queries the modulation type. The modulation mode depends on the selected PSDU
		bit rate which depends on the selected physical layer mode (SOUR:BB:WLNN:MODE) . \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: modulation: BPSK| QPSK| DBPSK| DQPSK| CCK| PBCC"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:PSDU:MODulation?')
		return Conversions.str_to_scalar_enum(response, enums.ModulationF)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MopsCls:
	"""Mops commands group definition. 11 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mops", core, parent)

	@property
	def importPy(self):
		"""importPy commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_importPy'):
			from .ImportPy import ImportPyCls
			self._importPy = ImportPyCls(self._core, self._cmd_group)
		return self._importPy

	# noinspection PyTypeChecker
	def get_display(self) -> enums.IonoGridView:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:IONospheric:MOPS:DISPlay \n
		Snippet: value: enums.IonoGridView = driver.source.bb.gnss.atmospheric.ionospheric.mops.get_display() \n
		Toggles between indication of the vertical delay and GIVEI values. \n
			:return: display_type: GIVei| VDELay
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ATMospheric:IONospheric:MOPS:DISPlay?')
		return Conversions.str_to_scalar_enum(response, enums.IonoGridView)

	def set_display(self, display_type: enums.IonoGridView) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:IONospheric:MOPS:DISPlay \n
		Snippet: driver.source.bb.gnss.atmospheric.ionospheric.mops.set_display(display_type = enums.IonoGridView.GIVei) \n
		Toggles between indication of the vertical delay and GIVEI values. \n
			:param display_type: GIVei| VDELay
		"""
		param = Conversions.enum_scalar_to_str(display_type, enums.IonoGridView)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ATMospheric:IONospheric:MOPS:DISPlay {param}')

	def export(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:IONospheric:MOPS:EXPort \n
		Snippet: driver.source.bb.gnss.atmospheric.ionospheric.mops.export(filename = 'abc') \n
		Saves the current ionospheric grid configuration in a file. \n
			:param filename: string Specify the file path, filename and extension. Allowed file extensions are *.rs_ion or *.iono_grid.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ATMospheric:IONospheric:MOPS:EXPort {param}')

	def get_file(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:IONospheric:MOPS:FILE \n
		Snippet: value: str = driver.source.bb.gnss.atmospheric.ionospheric.mops.get_file() \n
		Select a ionospheric grid file. \n
			:return: filename: string To load a predefined file, specify only the filename. To load a user-defined file, specify the absolute file path with filename and extension (*.iono_grid) .
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ATMospheric:IONospheric:MOPS:FILE?')
		return trim_str_response(response)

	def set_file(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:IONospheric:MOPS:FILE \n
		Snippet: driver.source.bb.gnss.atmospheric.ionospheric.mops.set_file(filename = 'abc') \n
		Select a ionospheric grid file. \n
			:param filename: string To load a predefined file, specify only the filename. To load a user-defined file, specify the absolute file path with filename and extension (*.iono_grid) .
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ATMospheric:IONospheric:MOPS:FILE {param}')

	def clone(self) -> 'MopsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MopsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FifoCls:
	"""Fifo commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fifo", core, parent)

	# noinspection PyTypeChecker
	def get_status(self) -> enums.SampRateFifoStatus:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:DIGital:SRATe:FIFO:[STATus] \n
		Snippet: value: enums.SampRateFifoStatus = driver.source.iq.output.digital.symbolRate.fifo.get_status() \n
		No command help available \n
			:return: status: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:DIGital:SRATe:FIFO:STATus?')
		return Conversions.str_to_scalar_enum(response, enums.SampRateFifoStatus)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IndexCls:
	"""Index commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("index", core, parent)

	def set(self, index: int, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:USER<ST>:MAC:INDex \n
		Snippet: driver.source.bb.evdo.user.mac.index.set(index = 1, userIx = repcap.UserIx.Default) \n
		Sets the MAC Index used for the selected user. MAC Index has to be different for the different users. However, in case
		that two users are using the same value for MAC Index, the lower priority user is disabled, or be unable to enable. The
		values for the MAC Indexes for the other users (see [:SOURce<hw>]:BB:EVDO:ANETwork:OUCount) are assigned from a pool of
		valid MAC Indexes. \n
			:param index: integer Range: 5 to 63 for physical layer subtype 0&1, 6 to 127 for physical layer subtype 2, 4 to 383 for physical layer subtype 3
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.decimal_value_to_str(index)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:USER{userIx_cmd_val}:MAC:INDex {param}')

	def get(self, userIx=repcap.UserIx.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EVDO:USER<ST>:MAC:INDex \n
		Snippet: value: int = driver.source.bb.evdo.user.mac.index.get(userIx = repcap.UserIx.Default) \n
		Sets the MAC Index used for the selected user. MAC Index has to be different for the different users. However, in case
		that two users are using the same value for MAC Index, the lower priority user is disabled, or be unable to enable. The
		values for the MAC Indexes for the other users (see [:SOURce<hw>]:BB:EVDO:ANETwork:OUCount) are assigned from a pool of
		valid MAC Indexes. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: index: integer Range: 5 to 63 for physical layer subtype 0&1, 6 to 127 for physical layer subtype 2, 4 to 383 for physical layer subtype 3"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EVDO:USER{userIx_cmd_val}:MAC:INDex?')
		return Conversions.str_to_int(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal.Utilities import trim_str_response
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PatternCls:
	"""Pattern commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pattern", core, parent)

	def get(self, frameIx=repcap.FrameIx.Default, slotNull=repcap.SlotNull.Default, subchannel=repcap.Subchannel.Default, userIx=repcap.UserIx.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:SLOT<ST0>:[SUBChannel<US>]:[USER<CH>]:DUMMy:MIXed:PATTern \n
		Snippet: value: str = driver.source.bb.gsm.frame.slot.subChannel.user.dummy.mixed.pattern.get(frameIx = repcap.FrameIx.Default, slotNull = repcap.SlotNull.Default, subchannel = repcap.Subchannel.Default, userIx = repcap.UserIx.Default) \n
		This command outputs the bit pattern of the Mixed field of the Dummy burst. The contents of the Mixed field is fixed and
		specified by the standard, the length is 142 bits. \n
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: pattern: 142 bits"""
		frameIx_cmd_val = self._cmd_group.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:SLOT{slotNull_cmd_val}:SUBChannel{subchannel_cmd_val}:USER{userIx_cmd_val}:DUMMy:MIXed:PATTern?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CopyCls:
	"""Copy commands group definition. 4 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("copy", core, parent)

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import ExecuteCls
			self._execute = ExecuteCls(self._core, self._cmd_group)
		return self._execute

	def get_coffset(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:C2K:COPY:COFFset \n
		Snippet: value: int = driver.source.bb.c2K.copy.get_coffset() \n
		The command sets the offset for the Walsh code in the destination base station. The minimum value is 0 (Walsh codes are
		identical) , the maximum value is 255. This command is only available in the downlink (SOUR:BB:C2K:LINK FORW/DOWN) . \n
			:return: coffset: integer Range: 0 to 255
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:C2K:COPY:COFFset?')
		return Conversions.str_to_int(response)

	def set_coffset(self, coffset: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:COPY:COFFset \n
		Snippet: driver.source.bb.c2K.copy.set_coffset(coffset = 1) \n
		The command sets the offset for the Walsh code in the destination base station. The minimum value is 0 (Walsh codes are
		identical) , the maximum value is 255. This command is only available in the downlink (SOUR:BB:C2K:LINK FORW/DOWN) . \n
			:param coffset: integer Range: 0 to 255
		"""
		param = Conversions.decimal_value_to_str(coffset)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:COPY:COFFset {param}')

	# noinspection PyTypeChecker
	def get_destination(self) -> enums.NumberA:
		"""SCPI: [SOURce<HW>]:BB:C2K:COPY:DESTination \n
		Snippet: value: enums.NumberA = driver.source.bb.c2K.copy.get_destination() \n
		The command selects the station to which data is to be copied. Whether the data is copied to a base station or a mobile
		station depends on which transmission direction is selected (command C2K:LINK UP | DOWN) . \n
			:return: destination: 1| 2| 3| 4 Range: 1 to 4
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:C2K:COPY:DESTination?')
		return Conversions.str_to_scalar_enum(response, enums.NumberA)

	def set_destination(self, destination: enums.NumberA) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:COPY:DESTination \n
		Snippet: driver.source.bb.c2K.copy.set_destination(destination = enums.NumberA._1) \n
		The command selects the station to which data is to be copied. Whether the data is copied to a base station or a mobile
		station depends on which transmission direction is selected (command C2K:LINK UP | DOWN) . \n
			:param destination: 1| 2| 3| 4 Range: 1 to 4
		"""
		param = Conversions.enum_scalar_to_str(destination, enums.NumberA)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:COPY:DESTination {param}')

	# noinspection PyTypeChecker
	def get_source(self) -> enums.NumberA:
		"""SCPI: [SOURce<HW>]:BB:C2K:COPY:SOURce \n
		Snippet: value: enums.NumberA = driver.source.bb.c2K.copy.get_source() \n
		The command selects the station that has data to be copied. Whether the station copied is a base or mobile station
		depends on which transmission direction is selected (command C2K:LINK UP | DOWN) . \n
			:return: source: 1| 2| 3| 4 Range: 1 to 4
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:C2K:COPY:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.NumberA)

	def set_source(self, source: enums.NumberA) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:COPY:SOURce \n
		Snippet: driver.source.bb.c2K.copy.set_source(source = enums.NumberA._1) \n
		The command selects the station that has data to be copied. Whether the station copied is a base or mobile station
		depends on which transmission direction is selected (command C2K:LINK UP | DOWN) . \n
			:param source: 1| 2| 3| 4 Range: 1 to 4
		"""
		param = Conversions.enum_scalar_to_str(source, enums.NumberA)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:COPY:SOURce {param}')

	def clone(self) -> 'CopyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CopyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TgplCls:
	"""Tgpl commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tgpl", core, parent)

	def set(self, tgpl: int, baseStation=repcap.BaseStation.Default, patternIx=repcap.PatternIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CMODe:PATTern<CH>:TGPL \n
		Snippet: driver.source.bb.w3Gpp.bstation.cmode.pattern.tgpl.set(tgpl = 1, baseStation = repcap.BaseStation.Default, patternIx = repcap.PatternIx.Default) \n
		The command sets the transmission gap pattern lengths. Setting 0 is available only for pattern 2. The transmission gap
		pattern length of the user equipment with the same suffix as the selected base station is set to the same value. \n
			:param tgpl: integer Range: 0 to 100
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param patternIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pattern')
		"""
		param = Conversions.decimal_value_to_str(tgpl)
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		patternIx_cmd_val = self._cmd_group.get_repcap_cmd_value(patternIx, repcap.PatternIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CMODe:PATTern{patternIx_cmd_val}:TGPL {param}')

	def get(self, baseStation=repcap.BaseStation.Default, patternIx=repcap.PatternIx.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CMODe:PATTern<CH>:TGPL \n
		Snippet: value: int = driver.source.bb.w3Gpp.bstation.cmode.pattern.tgpl.get(baseStation = repcap.BaseStation.Default, patternIx = repcap.PatternIx.Default) \n
		The command sets the transmission gap pattern lengths. Setting 0 is available only for pattern 2. The transmission gap
		pattern length of the user equipment with the same suffix as the selected base station is set to the same value. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param patternIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pattern')
			:return: tgpl: integer Range: 0 to 100"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		patternIx_cmd_val = self._cmd_group.get_repcap_cmd_value(patternIx, repcap.PatternIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CMODe:PATTern{patternIx_cmd_val}:TGPL?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 8 total commands, 2 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def error(self):
		"""error commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_error'):
			from .Error import ErrorCls
			self._error = ErrorCls(self._core, self._cmd_group)
		return self._error

	@property
	def trigger(self):
		"""trigger commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	def get_frequency(self) -> int:
		"""SCPI: TEST:BB:DATA:FREQuency \n
		Snippet: value: int = driver.test.bb.data.get_frequency() \n
		Sets the clock frequency for the BER/BLER test generator. \n
			:return: clock: integer Range: 100 to 1E8
		"""
		response = self._core.io.query_str('TEST:BB:DATA:FREQuency?')
		return Conversions.str_to_int(response)

	def set_frequency(self, clock: int) -> None:
		"""SCPI: TEST:BB:DATA:FREQuency \n
		Snippet: driver.test.bb.data.set_frequency(clock = 1) \n
		Sets the clock frequency for the BER/BLER test generator. \n
			:param clock: integer Range: 100 to 1E8
		"""
		param = Conversions.decimal_value_to_str(clock)
		self._core.io.write(f'TEST:BB:DATA:FREQuency {param}')

	def get_off_time(self) -> int:
		"""SCPI: TEST:BB:DATA:OFFTime \n
		Snippet: value: int = driver.test.bb.data.get_off_time() \n
		Sets the on/off time of the data enable time interval of the BER/BLER test generator. \n
			:return: off_time: integer Range: 0 to 4294967295, Unit: Bit
		"""
		response = self._core.io.query_str('TEST:BB:DATA:OFFTime?')
		return Conversions.str_to_int(response)

	def set_off_time(self, off_time: int) -> None:
		"""SCPI: TEST:BB:DATA:OFFTime \n
		Snippet: driver.test.bb.data.set_off_time(off_time = 1) \n
		Sets the on/off time of the data enable time interval of the BER/BLER test generator. \n
			:param off_time: integer Range: 0 to 4294967295, Unit: Bit
		"""
		param = Conversions.decimal_value_to_str(off_time)
		self._core.io.write(f'TEST:BB:DATA:OFFTime {param}')

	def get_ontime(self) -> int:
		"""SCPI: TEST:BB:DATA:ONTime \n
		Snippet: value: int = driver.test.bb.data.get_ontime() \n
		Sets the on/off time of the data enable time interval of the BER/BLER test generator. \n
			:return: ontime: No help available
		"""
		response = self._core.io.query_str('TEST:BB:DATA:ONTime?')
		return Conversions.str_to_int(response)

	def set_ontime(self, ontime: int) -> None:
		"""SCPI: TEST:BB:DATA:ONTime \n
		Snippet: driver.test.bb.data.set_ontime(ontime = 1) \n
		Sets the on/off time of the data enable time interval of the BER/BLER test generator. \n
			:param ontime: integer Range: 0 to 4294967295, Unit: Bit
		"""
		param = Conversions.decimal_value_to_str(ontime)
		self._core.io.write(f'TEST:BB:DATA:ONTime {param}')

	def get_rdelay(self) -> int:
		"""SCPI: TEST:BB:DATA:RDELay \n
		Snippet: value: int = driver.test.bb.data.get_rdelay() \n
		For 'External Restart = On, sets the delay time for the restart signal of the BER/BLER test generator. \n
			:return: restart_delay: integer Range: 0 to 4294967295
		"""
		response = self._core.io.query_str('TEST:BB:DATA:RDELay?')
		return Conversions.str_to_int(response)

	def set_rdelay(self, restart_delay: int) -> None:
		"""SCPI: TEST:BB:DATA:RDELay \n
		Snippet: driver.test.bb.data.set_rdelay(restart_delay = 1) \n
		For 'External Restart = On, sets the delay time for the restart signal of the BER/BLER test generator. \n
			:param restart_delay: integer Range: 0 to 4294967295
		"""
		param = Conversions.decimal_value_to_str(restart_delay)
		self._core.io.write(f'TEST:BB:DATA:RDELay {param}')

	def get_state(self) -> bool:
		"""SCPI: TEST:BB:DATA:STATe \n
		Snippet: value: bool = driver.test.bb.data.get_state() \n
		Activates the test generator for the bit or block error rate measurement. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('TEST:BB:DATA:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: TEST:BB:DATA:STATe \n
		Snippet: driver.test.bb.data.set_state(state = False) \n
		Activates the test generator for the bit or block error rate measurement. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'TEST:BB:DATA:STATe {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.BertTestMode:
		"""SCPI: TEST:BB:DATA:TYPE \n
		Snippet: value: enums.BertTestMode = driver.test.bb.data.get_type_py() \n
		Selects the type of error measurement. \n
			:return: type_py: BER| BLER
		"""
		response = self._core.io.query_str('TEST:BB:DATA:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.BertTestMode)

	def set_type_py(self, type_py: enums.BertTestMode) -> None:
		"""SCPI: TEST:BB:DATA:TYPE \n
		Snippet: driver.test.bb.data.set_type_py(type_py = enums.BertTestMode.BER) \n
		Selects the type of error measurement. \n
			:param type_py: BER| BLER
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.BertTestMode)
		self._core.io.write(f'TEST:BB:DATA:TYPE {param}')

	def clone(self) -> 'DataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CcodingCls:
	"""Ccoding commands group definition. 7 total commands, 0 Subgroups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ccoding", core, parent)

	def get_mib(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:CCODing:MIB \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.niot.ccoding.get_mib() \n
		Enables transmission of MIB data. \n
			:return: mib_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:CCODing:MIB?')
		return Conversions.str_to_bool(response)

	def set_mib(self, mib_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:CCODing:MIB \n
		Snippet: driver.source.bb.eutra.downlink.niot.ccoding.set_mib(mib_state = False) \n
		Enables transmission of MIB data. \n
			:param mib_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(mib_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:CCODing:MIB {param}')

	def get_mspare(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:CCODing:MSPare \n
		Snippet: value: str = driver.source.bb.eutra.downlink.niot.ccoding.get_mspare() \n
		Sets the 11 spare bits in the NPBCH transmission. \n
			:return: mib_spare_bits: 11-bits
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:CCODing:MSPare?')
		return trim_str_response(response)

	def set_mspare(self, mib_spare_bits: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:CCODing:MSPare \n
		Snippet: driver.source.bb.eutra.downlink.niot.ccoding.set_mspare(mib_spare_bits = rawAbc) \n
		Sets the 11 spare bits in the NPBCH transmission. \n
			:param mib_spare_bits: 11-bits
		"""
		param = Conversions.value_to_str(mib_spare_bits)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:CCODing:MSPare {param}')

	def get_ncid(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:CCODing:NCID \n
		Snippet: value: int = driver.source.bb.eutra.downlink.niot.ccoding.get_ncid() \n
		Queries the NCell ID. \n
			:return: ncell_id: integer Range: 0 to 503
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:CCODing:NCID?')
		return Conversions.str_to_int(response)

	def get_rsib(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:CCODing:RSIB \n
		Snippet: value: int = driver.source.bb.eutra.downlink.niot.ccoding.get_rsib() \n
		Queries the number of repetitions of the NDPSCH that carries SIB1-NB. \n
			:return: repetition_sib_1: integer Range: 0 to 16
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:CCODing:RSIB?')
		return Conversions.str_to_int(response)

	def get_sib(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:CCODing:SIB \n
		Snippet: value: int = driver.source.bb.eutra.downlink.niot.ccoding.get_sib() \n
		Sets the parameter scheduling info SIB1. \n
			:return: scheduling_sib_1: integer Range: 0 to 15
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:CCODing:SIB?')
		return Conversions.str_to_int(response)

	def set_sib(self, scheduling_sib_1: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:CCODing:SIB \n
		Snippet: driver.source.bb.eutra.downlink.niot.ccoding.set_sib(scheduling_sib_1 = 1) \n
		Sets the parameter scheduling info SIB1. \n
			:param scheduling_sib_1: integer Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(scheduling_sib_1)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:CCODing:SIB {param}')

	def get_soffset(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:CCODing:SOFFset \n
		Snippet: value: float = driver.source.bb.eutra.downlink.niot.ccoding.get_soffset() \n
		Sets the start SFN value. \n
			:return: sfn_offset: float Range: 0 to 1020
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:CCODing:SOFFset?')
		return Conversions.str_to_float(response)

	def set_soffset(self, sfn_offset: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:CCODing:SOFFset \n
		Snippet: driver.source.bb.eutra.downlink.niot.ccoding.set_soffset(sfn_offset = 1.0) \n
		Sets the start SFN value. \n
			:param sfn_offset: float Range: 0 to 1020
		"""
		param = Conversions.decimal_value_to_str(sfn_offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:CCODing:SOFFset {param}')

	def get_stfsib_1(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:CCODing:STFSib1 \n
		Snippet: value: int = driver.source.bb.eutra.downlink.niot.ccoding.get_stfsib_1() \n
		Queries the first frame in that the NPDSCH transmission carrying SIB1-NB is allocated. \n
			:return: sib_1_start_frame: integer Range: 0 to 11
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:CCODing:STFSib1?')
		return Conversions.str_to_int(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModulationCls:
	"""Modulation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("modulation", core, parent)

	def set(self, modulation: enums.HsUpaMod, mobileStation=repcap.MobileStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:[HSUPa]:DPCCh:E:FRC:MODulation \n
		Snippet: driver.source.bb.w3Gpp.mstation.hsupa.dpcch.e.frc.modulation.set(modulation = enums.HsUpaMod.BPSK, mobileStation = repcap.MobileStation.Default) \n
		Sets the modulation used for the selected FRC. Two modulation schemes are defined: BPSK for FRC 1 - 7 and 4PAM (4
		Pulse-Amplitude Modulation) for FRC 8. \n
			:param modulation: BPSK| PAM4
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
		"""
		param = Conversions.enum_scalar_to_str(modulation, enums.HsUpaMod)
		mobileStation_cmd_val = self._cmd_group.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:HSUPa:DPCCh:E:FRC:MODulation {param}')

	# noinspection PyTypeChecker
	def get(self, mobileStation=repcap.MobileStation.Default) -> enums.HsUpaMod:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:[HSUPa]:DPCCh:E:FRC:MODulation \n
		Snippet: value: enums.HsUpaMod = driver.source.bb.w3Gpp.mstation.hsupa.dpcch.e.frc.modulation.get(mobileStation = repcap.MobileStation.Default) \n
		Sets the modulation used for the selected FRC. Two modulation schemes are defined: BPSK for FRC 1 - 7 and 4PAM (4
		Pulse-Amplitude Modulation) for FRC 8. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: modulation: BPSK| PAM4"""
		mobileStation_cmd_val = self._cmd_group.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:HSUPa:DPCCh:E:FRC:MODulation?')
		return Conversions.str_to_scalar_enum(response, enums.HsUpaMod)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RateCls:
	"""Rate commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rate", core, parent)

	@property
	def index(self):
		"""index commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_index'):
			from .Index import IndexCls
			self._index = IndexCls(self._core, self._cmd_group)
		return self._index

	# noinspection PyTypeChecker
	def get(self, userIx=repcap.UserIx.Default) -> enums.EvdoDataRate:
		"""SCPI: [SOURce<HW>]:BB:EVDO:USER<ST>:RATE \n
		Snippet: value: enums.EvdoDataRate = driver.source.bb.evdo.user.rate.get(userIx = repcap.UserIx.Default) \n
		Queries the data rate of the packets sent to the selected user. Note: Selected rate becomes effective at the beginning of
		the next packet transmitted to the selected user. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: rate: DR4K8| DR9K6| DR19K2| DR38K4| DR76K8| DR153K6| DR307K2| DR614K4| DR921K6| DR1228K8| DR1536K| DR1843K2| DR2457K6| DR3072K| DR460K8| DR768K| DR1075K2| DR2150K4| DR3686K4| DR4300K8| DR4915K2"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EVDO:USER{userIx_cmd_val}:RATE?')
		return Conversions.str_to_scalar_enum(response, enums.EvdoDataRate)

	def clone(self) -> 'RateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IlsCls:
	"""Ils commands group definition. 100 total commands, 7 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ils", core, parent)

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import ClockCls
			self._clock = ClockCls(self._core, self._cmd_group)
		return self._clock

	@property
	def localizer(self):
		"""localizer commands group. 6 Sub-classes, 3 commands."""
		if not hasattr(self, '_localizer'):
			from .Localizer import LocalizerCls
			self._localizer = LocalizerCls(self._core, self._cmd_group)
		return self._localizer

	@property
	def setting(self):
		"""setting commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_setting'):
			from .Setting import SettingCls
			self._setting = SettingCls(self._core, self._cmd_group)
		return self._setting

	@property
	def trigger(self):
		"""trigger commands group. 4 Sub-classes, 4 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def gslope(self):
		"""gslope commands group. 5 Sub-classes, 3 commands."""
		if not hasattr(self, '_gslope'):
			from .Gslope import GslopeCls
			self._gslope = GslopeCls(self._core, self._cmd_group)
		return self._gslope

	@property
	def gs(self):
		"""gs commands group. 5 Sub-classes, 3 commands."""
		if not hasattr(self, '_gs'):
			from .Gs import GsCls
			self._gs = GsCls(self._core, self._cmd_group)
		return self._gs

	@property
	def mbeacon(self):
		"""mbeacon commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_mbeacon'):
			from .Mbeacon import MbeaconCls
			self._mbeacon = MbeaconCls(self._core, self._cmd_group)
		return self._mbeacon

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:PRESet \n
		Snippet: driver.source.bb.ils.preset() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:VOR|ILS|DME:STATe. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:PRESet \n
		Snippet: driver.source.bb.ils.preset_with_opc() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:VOR|ILS|DME:STATe. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:ILS:PRESet', opc_timeout_ms)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:STATe \n
		Snippet: value: bool = driver.source.bb.ils.get_state() \n
		Activates/deactivates the avionic standard. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:STATe \n
		Snippet: driver.source.bb.ils.set_state(state = False) \n
		Activates/deactivates the avionic standard. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:STATe {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.AvionicIlsType:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:TYPE \n
		Snippet: value: enums.AvionicIlsType = driver.source.bb.ils.get_type_py() \n
		Selects the ILS modulation type. \n
			:return: type_py: GS| LOCalize| GSLope| MBEacon
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicIlsType)

	def set_type_py(self, type_py: enums.AvionicIlsType) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:ILS:TYPE \n
		Snippet: driver.source.bb.ils.set_type_py(type_py = enums.AvionicIlsType.GS) \n
		Selects the ILS modulation type. \n
			:param type_py: GS| LOCalize| GSLope| MBEacon
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.AvionicIlsType)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:TYPE {param}')

	def clone(self) -> 'IlsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IlsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	@property
	def advanced(self):
		"""advanced commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_advanced'):
			from .Advanced import AdvancedCls
			self._advanced = AdvancedCls(self._core, self._cmd_group)
		return self._advanced

	def set(self, source: enums.SingExtAuto, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: TRIGger<HW>:LFFSweep:SOURce \n
		Snippet: driver.trigger.lffSweep.source.set(source = enums.SingExtAuto.AUTO, inputIx = repcap.InputIx.Default) \n
			INTRO_CMD_HELP: Selects the trigger source for the corresponding sweeps: \n
			- FSWeep - RF frequency
			- LFFSweep - LF frequency
			- PSWeep - RF level
			- SWEep - all sweeps
		The source names of the parameters correspond to the values provided in manual control of the instrument. They differ
		from the SCPI-compliant names, but the instrument accepts both variants. Use the SCPI name, if compatibility is an
		important issue. Find the corresponding SCPI-compliant commands in Cross-reference between the manual and remote control. \n
			:param source: AUTO| IMMediate | SINGle| BUS | EXTernal | EAUTo AUTO [IMMediate] Executes a sweep automatically. In this free-running mode, the trigger condition is met continuously. I.e. when a sweep is completed, the next one starts immediately. SINGle [BUS] Executes one complete sweep cycle. The following commands initiate a trigger event: *TRG [:SOURcehw]:SWEep:POWer:EXECute [:SOURcehw]:SWEep[:FREQuency]:EXECute method RsSmbv.Trigger.Sweep.Immediate.set, method RsSmbv.Trigger.Psweep.Immediate.set and method RsSmbv.Trigger.FreqSweep.Immediate.set. Set the sweep mode with the commands: [:SOURcehw]:SWEep:POWer:MODEAUTO|STEP [:SOURcehw]:SWEep[:FREQuency]:MODEAUTO|STEP [:SOURcehw]:LFOutput:SWEep[:FREQuency]:MODEAUTO|STEP In step mode (STEP) , the instrument executes only one step. EXTernal An external signal triggers the sweep. EAUTo An external signal triggers the sweep. When one sweep is finished, the next sweep starts. A second trigger event stops the sweep at the current frequency, a third trigger event starts the trigger at the start frequency, and so on.
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		param = Conversions.enum_scalar_to_str(source, enums.SingExtAuto)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'TRIGger{inputIx_cmd_val}:LFFSweep:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.SingExtAuto:
		"""SCPI: TRIGger<HW>:LFFSweep:SOURce \n
		Snippet: value: enums.SingExtAuto = driver.trigger.lffSweep.source.get(inputIx = repcap.InputIx.Default) \n
			INTRO_CMD_HELP: Selects the trigger source for the corresponding sweeps: \n
			- FSWeep - RF frequency
			- LFFSweep - LF frequency
			- PSWeep - RF level
			- SWEep - all sweeps
		The source names of the parameters correspond to the values provided in manual control of the instrument. They differ
		from the SCPI-compliant names, but the instrument accepts both variants. Use the SCPI name, if compatibility is an
		important issue. Find the corresponding SCPI-compliant commands in Cross-reference between the manual and remote control. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:return: source: AUTO| IMMediate | SINGle| BUS | EXTernal | EAUTo AUTO [IMMediate] Executes a sweep automatically. In this free-running mode, the trigger condition is met continuously. I.e. when a sweep is completed, the next one starts immediately. SINGle [BUS] Executes one complete sweep cycle. The following commands initiate a trigger event: *TRG [:SOURcehw]:SWEep:POWer:EXECute [:SOURcehw]:SWEep[:FREQuency]:EXECute method RsSmbv.Trigger.Sweep.Immediate.set, method RsSmbv.Trigger.Psweep.Immediate.set and method RsSmbv.Trigger.FreqSweep.Immediate.set. Set the sweep mode with the commands: [:SOURcehw]:SWEep:POWer:MODEAUTO|STEP [:SOURcehw]:SWEep[:FREQuency]:MODEAUTO|STEP [:SOURcehw]:LFOutput:SWEep[:FREQuency]:MODEAUTO|STEP In step mode (STEP) , the instrument executes only one step. EXTernal An external signal triggers the sweep. EAUTo An external signal triggers the sweep. When one sweep is finished, the next sweep starts. A second trigger event stops the sweep at the current frequency, a third trigger event starts the trigger at the start frequency, and so on."""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'TRIGger{inputIx_cmd_val}:LFFSweep:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.SingExtAuto)

	def clone(self) -> 'SourceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SourceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GsCls:
	"""Gs commands group definition. 14 total commands, 0 Subgroups, 14 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gs", core, parent)

	# noinspection PyTypeChecker
	def get_ant_subset(self) -> enums.EutraTcwaNtSubset:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:ANTSubset \n
		Snippet: value: enums.EutraTcwaNtSubset = driver.source.bb.eutra.tcw.gs.get_ant_subset() \n
		No command help available \n
			:return: antenna_subset: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:ANTSubset?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwaNtSubset)

	def set_ant_subset(self, antenna_subset: enums.EutraTcwaNtSubset) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:ANTSubset \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_ant_subset(antenna_subset = enums.EutraTcwaNtSubset.ALL) \n
		No command help available \n
			:param antenna_subset: No help available
		"""
		param = Conversions.enum_scalar_to_str(antenna_subset, enums.EutraTcwaNtSubset)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:ANTSubset {param}')

	# noinspection PyTypeChecker
	def get_bs_class(self) -> enums.UtraTcwbSclass:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:BSCLass \n
		Snippet: value: enums.UtraTcwbSclass = driver.source.bb.eutra.tcw.gs.get_bs_class() \n
		Sets the base station class. \n
			:return: bs_class: WIDE| LOCal| HOME| MEDium
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:BSCLass?')
		return Conversions.str_to_scalar_enum(response, enums.UtraTcwbSclass)

	def set_bs_class(self, bs_class: enums.UtraTcwbSclass) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:BSCLass \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_bs_class(bs_class = enums.UtraTcwbSclass.HOME) \n
		Sets the base station class. \n
			:param bs_class: WIDE| LOCal| HOME| MEDium
		"""
		param = Conversions.enum_scalar_to_str(bs_class, enums.UtraTcwbSclass)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:BSCLass {param}')

	# noinspection PyTypeChecker
	def get_gen_signals(self) -> enums.EutraTcwGeneratedSig:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:GENSignals \n
		Snippet: value: enums.EutraTcwGeneratedSig = driver.source.bb.eutra.tcw.gs.get_gen_signals() \n
		No command help available \n
			:return: generated_signal: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:GENSignals?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwGeneratedSig)

	def set_gen_signals(self, generated_signal: enums.EutraTcwGeneratedSig) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:GENSignals \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_gen_signals(generated_signal = enums.EutraTcwGeneratedSig.IF) \n
		No command help available \n
			:param generated_signal: No help available
		"""
		param = Conversions.enum_scalar_to_str(generated_signal, enums.EutraTcwGeneratedSig)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:GENSignals {param}')

	# noinspection PyTypeChecker
	def get_inst_setup(self) -> enums.EutraTcwiNstSetup:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:INSTsetup \n
		Snippet: value: enums.EutraTcwiNstSetup = driver.source.bb.eutra.tcw.gs.get_inst_setup() \n
		No command help available \n
			:return: instrument_setup: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:INSTsetup?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwiNstSetup)

	def set_inst_setup(self, instrument_setup: enums.EutraTcwiNstSetup) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:INSTsetup \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_inst_setup(instrument_setup = enums.EutraTcwiNstSetup.U1PATH) \n
		No command help available \n
			:param instrument_setup: No help available
		"""
		param = Conversions.enum_scalar_to_str(instrument_setup, enums.EutraTcwiNstSetup)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:INSTsetup {param}')

	# noinspection PyTypeChecker
	def get_marker_config(self) -> enums.EutraTcwMarkConf:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:MARKerconfig \n
		Snippet: value: enums.EutraTcwMarkConf = driver.source.bb.eutra.tcw.gs.get_marker_config() \n
		Selects the marker configuration. The marker can be used to synchronize the measuring equipment to the signal generator. \n
			:return: marker_config: UNCHanged| FRAMe FRAMe The marker settings are customized for the selected test case. 'Radio Frame Start' markers are output; the marker delays are set equal to zero. UNCHanged The current marker settings of the signal generator are retained unchanged.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:MARKerconfig?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwMarkConf)

	def set_marker_config(self, marker_config: enums.EutraTcwMarkConf) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:MARKerconfig \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_marker_config(marker_config = enums.EutraTcwMarkConf.FRAMe) \n
		Selects the marker configuration. The marker can be used to synchronize the measuring equipment to the signal generator. \n
			:param marker_config: UNCHanged| FRAMe FRAMe The marker settings are customized for the selected test case. 'Radio Frame Start' markers are output; the marker delays are set equal to zero. UNCHanged The current marker settings of the signal generator are retained unchanged.
		"""
		param = Conversions.enum_scalar_to_str(marker_config, enums.EutraTcwMarkConf)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:MARKerconfig {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.EutraTcwGsModeDefaultRange:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:MODE \n
		Snippet: value: enums.EutraTcwGsModeDefaultRange = driver.source.bb.eutra.tcw.gs.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwGsModeDefaultRange)

	def set_mode(self, mode: enums.EutraTcwGsModeDefaultRange) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:MODE \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_mode(mode = enums.EutraTcwGsModeDefaultRange.ADRate) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.EutraTcwGsModeDefaultRange)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:MODE {param}')

	# noinspection PyTypeChecker
	def get_option(self) -> enums.UtraTcwgsoPtion:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:OPTion \n
		Snippet: value: enums.UtraTcwgsoPtion = driver.source.bb.eutra.tcw.gs.get_option() \n
		No command help available \n
			:return: option: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:OPTion?')
		return Conversions.str_to_scalar_enum(response, enums.UtraTcwgsoPtion)

	def set_option(self, option: enums.UtraTcwgsoPtion) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:OPTion \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_option(option = enums.UtraTcwgsoPtion.OPT1) \n
		No command help available \n
			:param option: No help available
		"""
		param = Conversions.enum_scalar_to_str(option, enums.UtraTcwgsoPtion)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:OPTion {param}')

	# noinspection PyTypeChecker
	def get_release(self) -> enums.EutraTcwRelease:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:RELease \n
		Snippet: value: enums.EutraTcwRelease = driver.source.bb.eutra.tcw.gs.get_release() \n
		Sets the 3GPP test specification used as a guideline for the test cases. \n
			:return: release: REL8| REL9| REL10| REL11
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:RELease?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwRelease)

	def set_release(self, release: enums.EutraTcwRelease) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:RELease \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_release(release = enums.EutraTcwRelease.REL10) \n
		Sets the 3GPP test specification used as a guideline for the test cases. \n
			:param release: REL8| REL9| REL10| REL11
		"""
		param = Conversions.enum_scalar_to_str(release, enums.EutraTcwRelease)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:RELease {param}')

	# noinspection PyTypeChecker
	def get_rx_antennas(self) -> enums.EutraTcwNumOfRxAnt:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:RXANtennas \n
		Snippet: value: enums.EutraTcwNumOfRxAnt = driver.source.bb.eutra.tcw.gs.get_rx_antennas() \n
		No command help available \n
			:return: num_of_rx_antennas: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:RXANtennas?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwNumOfRxAnt)

	def set_rx_antennas(self, num_of_rx_antennas: enums.EutraTcwNumOfRxAnt) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:RXANtennas \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_rx_antennas(num_of_rx_antennas = enums.EutraTcwNumOfRxAnt.ANT1) \n
		No command help available \n
			:param num_of_rx_antennas: No help available
		"""
		param = Conversions.enum_scalar_to_str(num_of_rx_antennas, enums.EutraTcwNumOfRxAnt)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:RXANtennas {param}')

	# noinspection PyTypeChecker
	def get_sig_rout(self) -> enums.EutraTcwSignalRout:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:SIGRout \n
		Snippet: value: enums.EutraTcwSignalRout = driver.source.bb.eutra.tcw.gs.get_sig_rout() \n
		Selects the signal routing for baseband A signal which usually represents the wanted signal. \n
			:return: signal_routing: PORTA
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:SIGRout?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwSignalRout)

	def set_sig_rout(self, signal_routing: enums.EutraTcwSignalRout) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:SIGRout \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_sig_rout(signal_routing = enums.EutraTcwSignalRout.PORTA) \n
		Selects the signal routing for baseband A signal which usually represents the wanted signal. \n
			:param signal_routing: PORTA
		"""
		param = Conversions.enum_scalar_to_str(signal_routing, enums.EutraTcwSignalRout)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:SIGRout {param}')

	# noinspection PyTypeChecker
	def get_spec(self) -> enums.UtraTcwsPec:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:SPEC \n
		Snippet: value: enums.UtraTcwsPec = driver.source.bb.eutra.tcw.gs.get_spec() \n
		Selects the 3GPP test specification used as a guideline for the test cases. \n
			:return: gs_spec: TS36141
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:SPEC?')
		return Conversions.str_to_scalar_enum(response, enums.UtraTcwsPec)

	def set_spec(self, gs_spec: enums.UtraTcwsPec) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:SPEC \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_spec(gs_spec = enums.UtraTcwsPec.TS36141) \n
		Selects the 3GPP test specification used as a guideline for the test cases. \n
			:param gs_spec: TS36141
		"""
		param = Conversions.enum_scalar_to_str(gs_spec, enums.UtraTcwsPec)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:SPEC {param}')

	# noinspection PyTypeChecker
	def get_stc(self) -> enums.UtraTcwgssUbtest:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:STC \n
		Snippet: value: enums.UtraTcwgssUbtest = driver.source.bb.eutra.tcw.gs.get_stc() \n
		No command help available \n
			:return: sub_test_case: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:STC?')
		return Conversions.str_to_scalar_enum(response, enums.UtraTcwgssUbtest)

	def set_stc(self, sub_test_case: enums.UtraTcwgssUbtest) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:STC \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_stc(sub_test_case = enums.UtraTcwgssUbtest.STC1) \n
		No command help available \n
			:param sub_test_case: No help available
		"""
		param = Conversions.enum_scalar_to_str(sub_test_case, enums.UtraTcwgssUbtest)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:STC {param}')

	# noinspection PyTypeChecker
	def get_trigger_config(self) -> enums.EutraTcwtRigConf:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:TRIGgerconfig \n
		Snippet: value: enums.EutraTcwtRigConf = driver.source.bb.eutra.tcw.gs.get_trigger_config() \n
		Selects the trigger configuration. The trigger is used to synchronize the signal generator to the other equipment. \n
			:return: trigger_config: UNCHanged| AAUTo UNCHanged The current trigger settings of the signal generator are retained unchanged. AAUTo The trigger settings are customized for the selected test case. The trigger setting 'Armed Auto' with external trigger source is used; the trigger delay is set to zero. Thus, the base station frame timing is able to synchronize the signal generator by a periodic trigger.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:TRIGgerconfig?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwtRigConf)

	def set_trigger_config(self, trigger_config: enums.EutraTcwtRigConf) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:TRIGgerconfig \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_trigger_config(trigger_config = enums.EutraTcwtRigConf.AAUTo) \n
		Selects the trigger configuration. The trigger is used to synchronize the signal generator to the other equipment. \n
			:param trigger_config: UNCHanged| AAUTo UNCHanged The current trigger settings of the signal generator are retained unchanged. AAUTo The trigger settings are customized for the selected test case. The trigger setting 'Armed Auto' with external trigger source is used; the trigger delay is set to zero. Thus, the base station frame timing is able to synchronize the signal generator by a periodic trigger.
		"""
		param = Conversions.enum_scalar_to_str(trigger_config, enums.EutraTcwtRigConf)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:TRIGgerconfig {param}')

	# noinspection PyTypeChecker
	def get_tx_antennas(self) -> enums.TxAntenna:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:TXANtennas \n
		Snippet: value: enums.TxAntenna = driver.source.bb.eutra.tcw.gs.get_tx_antennas() \n
		No command help available \n
			:return: num_of_tx_antennas: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:GS:TXANtennas?')
		return Conversions.str_to_scalar_enum(response, enums.TxAntenna)

	def set_tx_antennas(self, num_of_tx_antennas: enums.TxAntenna) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:GS:TXANtennas \n
		Snippet: driver.source.bb.eutra.tcw.gs.set_tx_antennas(num_of_tx_antennas = enums.TxAntenna.ANT1) \n
		No command help available \n
			:param num_of_tx_antennas: No help available
		"""
		param = Conversions.enum_scalar_to_str(num_of_tx_antennas, enums.TxAntenna)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:GS:TXANtennas {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NtpCls:
	"""Ntp commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ntp", core, parent)

	def get_hostname(self) -> str:
		"""SCPI: SYSTem:NTP:HOSTname \n
		Snippet: value: str = driver.system.ntp.get_hostname() \n
		Sets the address of the NTP server. You can enter the IP address, or the hostname of the time server, or even set up an
		own vendor zone. See the Internet for more information on NTP. \n
			:return: ntp_name: string
		"""
		response = self._core.io.query_str('SYSTem:NTP:HOSTname?')
		return trim_str_response(response)

	def set_hostname(self, ntp_name: str) -> None:
		"""SCPI: SYSTem:NTP:HOSTname \n
		Snippet: driver.system.ntp.set_hostname(ntp_name = 'abc') \n
		Sets the address of the NTP server. You can enter the IP address, or the hostname of the time server, or even set up an
		own vendor zone. See the Internet for more information on NTP. \n
			:param ntp_name: string
		"""
		param = Conversions.value_to_quoted_str(ntp_name)
		self._core.io.write(f'SYSTem:NTP:HOSTname {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SuPolicyCls:
	"""SuPolicy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("suPolicy", core, parent)

	def set(self, sec_pass_word: str, update_policy: enums.UpdPolicyMode) -> None:
		"""SCPI: SYSTem:SECurity:SUPolicy \n
		Snippet: driver.system.security.suPolicy.set(sec_pass_word = 'abc', update_policy = enums.UpdPolicyMode.CONFirm) \n
		Configures the automatic signature verification for firmware installation. \n
			:param sec_pass_word: string
			:param update_policy: STRict| CONFirm| IGNore
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('sec_pass_word', sec_pass_word, DataType.String), ArgSingle('update_policy', update_policy, DataType.Enum, enums.UpdPolicyMode))
		self._core.io.write(f'SYSTem:SECurity:SUPolicy {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self) -> enums.UpdPolicyMode:
		"""SCPI: SYSTem:SECurity:SUPolicy \n
		Snippet: value: enums.UpdPolicyMode = driver.system.security.suPolicy.get() \n
		Configures the automatic signature verification for firmware installation. \n
			:return: update_policy: STRict| CONFirm| IGNore"""
		response = self._core.io.query_str(f'SYSTem:SECurity:SUPolicy?')
		return Conversions.str_to_scalar_enum(response, enums.UpdPolicyMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OptimizationCls:
	"""Optimization commands group definition. 5 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("optimization", core, parent)

	@property
	def bandwidth(self):
		"""bandwidth commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def hold(self):
		"""hold commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hold'):
			from .Hold import HoldCls
			self._hold = HoldCls(self._core, self._cmd_group)
		return self._hold

	@property
	def local(self):
		"""local commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_local'):
			from .Local import LocalCls
			self._local = LocalCls(self._core, self._cmd_group)
		return self._local

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.OptimizationMode:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:OPTimization:MODE \n
		Snippet: value: enums.OptimizationMode = driver.source.correction.fresponse.rf.optimization.get_mode() \n
		Sets the optimization mode. The value selected here is used also as optimization mode in the I/Q modulator, and vice
		versa. See 'Optimization Mode'. \n
			:return: freq_resp_opt_mode: FAST| QHIGh FAST Optimization by compensation for I/Q skew. QHIGh Optimization by compensation for I/Q skew and frequency response correction. This mode interrupts the RF signal. Do not use it in combination with the uninterrupted level settings and strictly monotone modes RF level modes. These RF level modes can be set with the following command: [:SOURcehw]:POWer:LBEHaviour
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:FRESponse:RF:OPTimization:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.OptimizationMode)

	def set_mode(self, freq_resp_opt_mode: enums.OptimizationMode) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:OPTimization:MODE \n
		Snippet: driver.source.correction.fresponse.rf.optimization.set_mode(freq_resp_opt_mode = enums.OptimizationMode.FAST) \n
		Sets the optimization mode. The value selected here is used also as optimization mode in the I/Q modulator, and vice
		versa. See 'Optimization Mode'. \n
			:param freq_resp_opt_mode: FAST| QHIGh FAST Optimization by compensation for I/Q skew. QHIGh Optimization by compensation for I/Q skew and frequency response correction. This mode interrupts the RF signal. Do not use it in combination with the uninterrupted level settings and strictly monotone modes RF level modes. These RF level modes can be set with the following command: [:SOURcehw]:POWer:LBEHaviour
		"""
		param = Conversions.enum_scalar_to_str(freq_resp_opt_mode, enums.OptimizationMode)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:FRESponse:RF:OPTimization:MODE {param}')

	def clone(self) -> 'OptimizationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = OptimizationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CaAddressCls:
	"""CaAddress commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("caAddress", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Access_Address: str: No parameter help available
			- Bitcount: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Access_Address'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Access_Address: str = None
			self.Bitcount: int = None

	def get(self, channelNull=repcap.ChannelNull.Default, stepNull=repcap.StepNull.Default) -> GetStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CS:[SEVent<CH0>]:[STEP<ST0>]:CAADdress \n
		Snippet: value: GetStruct = driver.source.bb.btooth.cs.sevent.step.caAddress.get(channelNull = repcap.ChannelNull.Default, stepNull = repcap.StepNull.Default) \n
		No command help available \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sevent')
			:param stepNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Step')
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		stepNull_cmd_val = self._cmd_group.get_repcap_cmd_value(stepNull, repcap.StepNull)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:BTOoth:CS:SEVent{channelNull_cmd_val}:STEP{stepNull_cmd_val}:CAADdress?', self.__class__.GetStruct())



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PointCls:
	"""Point commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("point", core, parent)

	@property
	def configuration(self):
		"""configuration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_configuration'):
			from .Configuration import ConfigurationCls
			self._configuration = ConfigurationCls(self._core, self._cmd_group)
		return self._configuration

	def get_catalog(self) -> List[str]:
		"""SCPI: DIAGnostic<HW>:POINt:CATalog \n
		Snippet: value: List[str] = driver.diagnostic.point.get_catalog() \n
		Queries the test points available in the instrument. For more information, see R&S SMBV100B Service Manual. \n
			:return: catalog: string List of comma-separated values, each representing a test point
		"""
		response = self._core.io.query_str('DIAGnostic<HwInstance>:POINt:CATalog?')
		return Conversions.str_to_str_list(response)

	def clone(self) -> 'PointCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PointCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SkProcessCls:
	"""SkProcess commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("skProcess", core, parent)

	def set(self, skip_proc: bool, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:AS:DL:SKPRocess \n
		Snippet: driver.source.bb.eutra.downlink.user.asPy.downlink.skProcess.set(skip_proc = False, userIx = repcap.UserIx.Default) \n
		Skips HARQ process at unused subframes. \n
			:param skip_proc: 1| ON| 0| OFF
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.bool_to_str(skip_proc)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:AS:DL:SKPRocess {param}')

	def get(self, userIx=repcap.UserIx.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:AS:DL:SKPRocess \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.user.asPy.downlink.skProcess.get(userIx = repcap.UserIx.Default) \n
		Skips HARQ process at unused subframes. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: skip_proc: 1| ON| 0| OFF"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:AS:DL:SKPRocess?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DinSecCls:
	"""DinSec commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dinSec", core, parent)

	def get(self, output=repcap.Output.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TRIGger:OUTPut<CH>:DINSec \n
		Snippet: value: float = driver.source.bb.nr5G.trigger.output.dinSec.get(output = repcap.Output.Default) \n
		Queries the marker delay in microseconds.
		You can define a marker delay in samples with [:SOURce<hw>]:BB:NR5G:TRIGger:OUTPut<ch>:DELay. \n
			:param output: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: delay_in_seconds: float Range: 0 to 16777215"""
		output_cmd_val = self._cmd_group.get_repcap_cmd_value(output, repcap.Output)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:TRIGger:OUTPut{output_cmd_val}:DINSec?')
		return Conversions.str_to_float(response)



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RbOffsetCls:
	"""RbOffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rbOffset", core, parent)

	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, slotNull=repcap.SlotNull.Default, allocationNull=repcap.AllocationNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[CELL<CCIDX>]:[SUBF<ST0>]:SLOT<USER0>:ALLoc<CH0>:PUSCh:SET:RBOFfset \n
		Snippet: value: int = driver.source.bb.eutra.uplink.cell.subf.slot.alloc.pusch.set.rbOffset.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, slotNull = repcap.SlotNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Queries the start resource block of the selected allocation in slot n of the subframe. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: rb_offset: integer Range: 0 to 49"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:SLOT{slotNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:SET:RBOFfset?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SoffsetCls:
	"""Soffset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("soffset", core, parent)

	def set(self, soffset: int, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:USER<ST>:PACKet:SOFFset \n
		Snippet: driver.source.bb.evdo.user.packet.soffset.set(soffset = 1, userIx = repcap.UserIx.Default) \n
		Sets the minimum number of slots between the end of one packet and the beginning of the next. For single slot packets, a
		value of zero will cause the next packet to be sent in the immediate next slot (subject to scheduling) . For multiple
		slot packets, a value of zero will cause the next packet transmission to start three slots after the end of the previous
		packet. The three slot delay is identical to the interleaving delay between slots for multiple slot packets. The offset
		value is attached to the end of the preceding packet. \n
			:param soffset: integer Range: 0 to 255
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.decimal_value_to_str(soffset)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:USER{userIx_cmd_val}:PACKet:SOFFset {param}')

	def get(self, userIx=repcap.UserIx.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EVDO:USER<ST>:PACKet:SOFFset \n
		Snippet: value: int = driver.source.bb.evdo.user.packet.soffset.get(userIx = repcap.UserIx.Default) \n
		Sets the minimum number of slots between the end of one packet and the beginning of the next. For single slot packets, a
		value of zero will cause the next packet to be sent in the immediate next slot (subject to scheduling) . For multiple
		slot packets, a value of zero will cause the next packet transmission to start three slots after the end of the previous
		packet. The three slot delay is identical to the interleaving delay between slots for multiple slot packets. The offset
		value is attached to the end of the preceding packet. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: soffset: integer Range: 0 to 255"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EVDO:USER{userIx_cmd_val}:PACKet:SOFFset?')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WcodeCls:
	"""Wcode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("wcode", core, parent)

	def set(self, wcode: int, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:WCODe \n
		Snippet: driver.source.bb.c2K.bstation.cgroup.coffset.wcode.set(wcode = 1, baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		Assigns the Walsh Code to the channel. The standard assigns a fixed walsh code to some channels (F-PICH, for example,
		always uses Walsh code 0) . Generally, the Walsh code can only be varied within the range specified by the standard. For
		the traffic channels, this value is specific for the selected radio configuration. The value range of the Walsh code
		depends on the frame length, the channel coding type and the data rate. If one of these parameters is changed so that the
		set Walsh code gets invalid, the next permissible value is automatically set. \n
			:param wcode: integer Range: 0 to 255
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
		"""
		param = Conversions.decimal_value_to_str(wcode)
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:WCODe {param}')

	def get(self, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:WCODe \n
		Snippet: value: int = driver.source.bb.c2K.bstation.cgroup.coffset.wcode.get(baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		Assigns the Walsh Code to the channel. The standard assigns a fixed walsh code to some channels (F-PICH, for example,
		always uses Walsh code 0) . Generally, the Walsh code can only be varied within the range specified by the standard. For
		the traffic channels, this value is specific for the selected radio configuration. The value range of the Walsh code
		depends on the frame length, the channel coding type and the data rate. If one of these parameters is changed so that the
		set Walsh code gets invalid, the next permissible value is automatically set. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
			:return: wcode: integer Range: 0 to 255"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:WCODe?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DownlinkCls:
	"""Downlink commands group definition. 9 total commands, 3 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("downlink", core, parent)

	@property
	def dall(self):
		"""dall commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dall'):
			from .Dall import DallCls
			self._dall = DallCls(self._core, self._cmd_group)
		return self._dall

	@property
	def eall(self):
		"""eall commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_eall'):
			from .Eall import EallCls
			self._eall = EallCls(self._core, self._cmd_group)
		return self._eall

	@property
	def logPoint(self):
		"""logPoint commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_logPoint'):
			from .LogPoint import LogPointCls
			self._logPoint = LogPointCls(self._core, self._cmd_group)
		return self._logPoint

	def get_ed_logging(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:EDLogging \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.downlink.get_ed_logging() \n
		No command help available \n
			:return: ext_dci_log: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:EDLogging?')
		return Conversions.str_to_bool(response)

	def set_ed_logging(self, ext_dci_log: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:EDLogging \n
		Snippet: driver.source.bb.eutra.logGen.downlink.set_ed_logging(ext_dci_log = False) \n
		No command help available \n
			:param ext_dci_log: No help available
		"""
		param = Conversions.bool_to_str(ext_dci_log)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:EDLogging {param}')

	def get_encc(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:ENCC \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.downlink.get_encc() \n
		No command help available \n
			:return: encc_log_state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:ENCC?')
		return Conversions.str_to_bool(response)

	def set_encc(self, encc_log_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:ENCC \n
		Snippet: driver.source.bb.eutra.logGen.downlink.set_encc(encc_log_state = False) \n
		No command help available \n
			:param encc_log_state: No help available
		"""
		param = Conversions.bool_to_str(encc_log_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:ENCC {param}')

	def get_nwus(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:NWUS \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.downlink.get_nwus() \n
		No command help available \n
			:return: nwus: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:NWUS?')
		return Conversions.str_to_bool(response)

	def set_nwus(self, nwus: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:NWUS \n
		Snippet: driver.source.bb.eutra.logGen.downlink.set_nwus(nwus = False) \n
		No command help available \n
			:param nwus: No help available
		"""
		param = Conversions.bool_to_str(nwus)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:NWUS {param}')

	def get_pbch(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:PBCH \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.downlink.get_pbch() \n
		No command help available \n
			:return: pbch_log_state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:PBCH?')
		return Conversions.str_to_bool(response)

	def set_pbch(self, pbch_log_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:PBCH \n
		Snippet: driver.source.bb.eutra.logGen.downlink.set_pbch(pbch_log_state = False) \n
		No command help available \n
			:param pbch_log_state: No help available
		"""
		param = Conversions.bool_to_str(pbch_log_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:PBCH {param}')

	def get_pdsch(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:PDSCh \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.downlink.get_pdsch() \n
		No command help available \n
			:return: pdsch_log_state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:PDSCh?')
		return Conversions.str_to_bool(response)

	def set_pdsch(self, pdsch_log_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:PDSCh \n
		Snippet: driver.source.bb.eutra.logGen.downlink.set_pdsch(pdsch_log_state = False) \n
		No command help available \n
			:param pdsch_log_state: No help available
		"""
		param = Conversions.bool_to_str(pdsch_log_state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:PDSCh {param}')

	def get_pmch(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:PMCH \n
		Snippet: value: bool = driver.source.bb.eutra.logGen.downlink.get_pmch() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:PMCH?')
		return Conversions.str_to_bool(response)

	def set_pmch(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:LOGGen:DL:PMCH \n
		Snippet: driver.source.bb.eutra.logGen.downlink.set_pmch(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:LOGGen:DL:PMCH {param}')

	def clone(self) -> 'DownlinkCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DownlinkCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BsrsCls:
	"""Bsrs commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bsrs", core, parent)

	def set(self, bsrs: int, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:REFSig:SRS:BSRS \n
		Snippet: driver.source.bb.eutra.uplink.ue.cell.refsig.srs.bsrs.set(bsrs = 1, userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		Sets the UE-specific parameter SRS bandwidth BSRS. \n
			:param bsrs: integer Range: 0 to 3
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
		"""
		param = Conversions.decimal_value_to_str(bsrs)
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:REFSig:SRS:BSRS {param}')

	def get(self, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:[CELL<CCIDX>]:REFSig:SRS:BSRS \n
		Snippet: value: int = driver.source.bb.eutra.uplink.ue.cell.refsig.srs.bsrs.get(userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default) \n
		Sets the UE-specific parameter SRS bandwidth BSRS. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: bsrs: integer Range: 0 to 3"""
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:REFSig:SRS:BSRS?')
		return Conversions.str_to_int(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal.RepeatedCapability import RepeatedCapability
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FileCls:
	"""File commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: Index, default value after init: Index.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("file", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_index_get', 'repcap_index_set', repcap.Index.Nr1)

	def repcap_index_set(self, index: repcap.Index) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Index.Default
		Default value after init: Index.Nr1"""
		self._cmd_group.set_repcap_enum_value(index)

	def repcap_index_get(self) -> repcap.Index:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, index=repcap.Index.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:IMPort:SBAS:WAAS:REMove:FILE<CH> \n
		Snippet: driver.source.bb.gnss.sv.importPy.sbas.waas.remove.file.set(index = repcap.Index.Default) \n
		Removes one particular *.ems file for EGNOS correction data *.nstb file for WAAS correction data at the n-th position
		from the import file list. \n
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')
		"""
		index_cmd_val = self._cmd_group.get_repcap_cmd_value(index, repcap.Index)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:IMPort:SBAS:WAAS:REMove:FILE{index_cmd_val}')

	def set_with_opc(self, index=repcap.Index.Default, opc_timeout_ms: int = -1) -> None:
		index_cmd_val = self._cmd_group.get_repcap_cmd_value(index, repcap.Index)
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:IMPort:SBAS:WAAS:REMove:FILE<CH> \n
		Snippet: driver.source.bb.gnss.sv.importPy.sbas.waas.remove.file.set_with_opc(index = repcap.Index.Default) \n
		Removes one particular *.ems file for EGNOS correction data *.nstb file for WAAS correction data at the n-th position
		from the import file list. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:GNSS:SV:IMPort:SBAS:WAAS:REMove:FILE{index_cmd_val}', opc_timeout_ms)

	def clone(self) -> 'FileCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FileCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UkeyCls:
	"""Ukey commands group definition. 3 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ukey", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import AddCls
			self._add = AddCls(self._core, self._cmd_group)
		return self._add

	def set_name(self, name: str) -> None:
		"""SCPI: DISPlay:UKEY:NAME \n
		Snippet: driver.display.ukey.set_name(name = 'abc') \n
		No command help available \n
			:param name: No help available
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'DISPlay:UKEY:NAME {param}')

	def set_scpi(self, scpi: str) -> None:
		"""SCPI: DISPlay:UKEY:SCPI \n
		Snippet: driver.display.ukey.set_scpi(scpi = 'abc') \n
		No command help available \n
			:param scpi: No help available
		"""
		param = Conversions.value_to_quoted_str(scpi)
		self._core.io.write(f'DISPlay:UKEY:SCPI {param}')

	def clone(self) -> 'UkeyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UkeyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UlistCls:
	"""Ulist commands group definition. 4 total commands, 2 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ulist", core, parent)

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Catalog import CatalogCls
			self._catalog = CatalogCls(self._core, self._cmd_group)
		return self._catalog

	@property
	def store(self):
		"""store commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_store'):
			from .Store import StoreCls
			self._store = StoreCls(self._core, self._cmd_group)
		return self._store

	def delete(self, filename: str, frameIx=repcap.FrameIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:FRAMe<DI>:ULISt:DELete \n
		Snippet: driver.source.bb.gsm.frame.ulist.delete(filename = 'abc', frameIx = repcap.FrameIx.Default) \n
		This command deletes the selected file with user defined frame settings. The directory is set using command method RsSmbv.
		MassMemory.currentDirectory. A path can also be specified, in which case the files in the specified directory are read.
		The file extension can be omitted. Only files with the file extension *.gsm_fu and *.gsm_hfu are deleted. \n
			:param filename: string
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
		"""
		param = Conversions.value_to_quoted_str(filename)
		frameIx_cmd_val = self._cmd_group.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:ULISt:DELete {param}')

	def load(self, filename: str, frameIx=repcap.FrameIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:FRAMe<DI>:ULISt:LOAD \n
		Snippet: driver.source.bb.gsm.frame.ulist.load(filename = 'abc', frameIx = repcap.FrameIx.Default) \n
		This command loads the selected file with user defined frame settings. The directory is set using command method RsSmbv.
		MassMemory.currentDirectory. A path can also be specified, in which case the files in the specified directory are read.
		The file extension can be omitted. Only files with the file extension *.gsm_fu and *.gsm_hfu are loaded. \n
			:param filename: string
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
		"""
		param = Conversions.value_to_quoted_str(filename)
		frameIx_cmd_val = self._cmd_group.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:ULISt:LOAD {param}')

	def clone(self) -> 'UlistCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UlistCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AvrlCls:
	"""Avrl commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("avrl", core, parent)

	def get(self, rowNull=repcap.RowNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:POWer:BBConf:ROW<APR(CH0)>:AVRL \n
		Snippet: value: float = driver.source.bb.nr5G.output.power.bbConf.row.avrl.get(rowNull = repcap.RowNull.Default) \n
		Queries the available basebands with their average power. \n
			:param rowNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Row')
			:return: pow_per_bb_rel_lvl: float Range: -80 to 10"""
		rowNull_cmd_val = self._cmd_group.get_repcap_cmd_value(rowNull, repcap.RowNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:OUTPut:POWer:BBConf:ROW{rowNull_cmd_val}:AVRL?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class L2BandCls:
	"""L2Band commands group definition. 20 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("l2Band", core, parent)

	@property
	def ca(self):
		"""ca commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_ca'):
			from .Ca import CaCls
			self._ca = CaCls(self._core, self._cmd_group)
		return self._ca

	@property
	def l2Cdma(self):
		"""l2Cdma commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_l2Cdma'):
			from .L2Cdma import L2CdmaCls
			self._l2Cdma = L2CdmaCls(self._core, self._cmd_group)
		return self._l2Cdma

	def clone(self) -> 'L2BandCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = L2BandCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NiotCls:
	"""Niot commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("niot", core, parent)

	# noinspection PyTypeChecker
	def get_frc(self) -> enums.EutraUlFrcNbiotTcw:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:WS:NIOT:FRC \n
		Snippet: value: enums.EutraUlFrcNbiotTcw = driver.source.bb.eutra.tcw.ws.niot.get_frc() \n
		No command help available \n
			:return: nbiot_frc: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:WS:NIOT:FRC?')
		return Conversions.str_to_scalar_enum(response, enums.EutraUlFrcNbiotTcw)

	def set_frc(self, nbiot_frc: enums.EutraUlFrcNbiotTcw) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:WS:NIOT:FRC \n
		Snippet: driver.source.bb.eutra.tcw.ws.niot.set_frc(nbiot_frc = enums.EutraUlFrcNbiotTcw.A161) \n
		No command help available \n
			:param nbiot_frc: No help available
		"""
		param = Conversions.enum_scalar_to_str(nbiot_frc, enums.EutraUlFrcNbiotTcw)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:WS:NIOT:FRC {param}')
